@@ -59,3 +59,6 @@ class Code(str):
         if isinstance(other, Code):
             return (self.__scope, str(self)) == (other.__scope, str(other))
         return False
+
+    def __ne__(self, other):
+        return not self == other
