@@ -165,24 +165,39 @@ class Collection(object):
         """
         return self.__database
 
-    def save(self, to_save, manipulate=True, safe=False):
+    def save(self, to_save, manipulate=True, safe=False, **kwargs):
         """Save a document in this collection.
 
-        If `to_save` already has an '_id' then an update (upsert) operation
-        is performed and any existing document with that _id is overwritten.
-        Otherwise an '_id' will be added to `to_save` and an insert operation
-        is performed. Returns the _id of the saved document.
+        If `to_save` already has an ``"_id"`` then an :meth:`update`
+        (upsert) operation is performed and any existing document with
+        that ``"_id"`` is overwritten.  Otherwise an ``"_id"`` will be
+        added to `to_save` and an :meth:`insert` operation is
+        performed. Returns the ``"_id"`` of the saved document.
 
-        Raises TypeError if to_save is not an instance of dict. If `safe`
-        is True then the save will be checked for errors, raising
-        OperationFailure if one occurred. Safe inserts wait for a
-        response from the database, while normal inserts do not. Returns the
-        _id of the saved document.
+        Raises :class:`TypeError` if `to_save` is not an instance of
+        :class:`dict`. If `safe` is ``True`` then the save will be
+        checked for errors, raising
+        :class:`~pymongo.errors.OperationFailure` if one
+        occurred. Safe inserts wait for a response from the database,
+        while normal inserts do not.
+
+        Any additional keyword arguments imply ``safe=True``, and will
+        be used as options for the resultant `getLastError`
+        command. For example, to wait for replication to 3 nodes, pass
+        ``w=3``.
 
         :Parameters:
-          - `to_save`: the SON object to be saved
-          - `manipulate` (optional): manipulate the SON object before saving it
+          - `to_save`: the document to be saved
+          - `manipulate` (optional): manipulate the document before
+            saving it?
           - `safe` (optional): check that the save succeeded?
+          - `**kwargs` (optional): any additional arguments imply
+            ``safe=True``, and will be used as options for the
+            `getLastError` command
+
+        .. versionadded:: 1.8
+           Support for passing `getLastError` options as keyword
+           arguments.
 
         .. mongodoc:: insert
         """
@@ -190,31 +205,50 @@ class Collection(object):
             raise TypeError("cannot save object of type %s" % type(to_save))
 
         if "_id" not in to_save:
-            return self.insert(to_save, manipulate, safe)
+            return self.insert(to_save, manipulate, safe, **kwargs)
         else:
             self.update({"_id": to_save["_id"]}, to_save, True,
-                        manipulate, safe)
+                        manipulate, safe, **kwargs)
             return to_save.get("_id", None)
 
     def insert(self, doc_or_docs,
-               manipulate=True, safe=False, check_keys=True):
+               manipulate=True, safe=False, check_keys=True, **kwargs):
         """Insert a document(s) into this collection.
 
-        If manipulate is set the document(s) are manipulated using any
-        SONManipulators that have been added to this database. Returns the _id
-        of the inserted document or a list of _ids of the inserted documents.
-        If the document(s) does not already contain an '_id' one will be added.
-        If `safe` is True then the insert will be checked for errors, raising
-        OperationFailure if one occurred. Safe inserts wait for a response from
-        the database, while normal inserts do not.
+        If `manipulate` is set, the document(s) are manipulated using
+        any :class:`~pymongo.son_manipulator.SONManipulator` instances
+        that have been added to this
+        :class:`~pymongo.database.Database`. Returns the ``"_id"`` of
+        the inserted document or a list of ``"_id"`` values of the
+        inserted documents.  If the document(s) does not already
+        contain an ``"_id"`` one will be added.
+
+        If `safe` is ``True`` then the insert will be checked for
+        errors, raising :class:`~pymongo.errors.OperationFailure` if
+        one occurred. Safe inserts wait for a response from the
+        database, while normal inserts do not.
+
+        Any additional keyword arguments imply ``safe=True``, and
+        will be used as options for the resultant `getLastError`
+        command. For example, to wait for replication to 3 nodes, pass
+        ``w=3``.
 
         :Parameters:
-          - `doc_or_docs`: a SON object or list of SON objects to be inserted
-          - `manipulate` (optional): manipulate the documents before inserting?
+          - `doc_or_docs`: a document or list of documents to be
+            inserted
+          - `manipulate` (optional): manipulate the documents before
+            inserting?
           - `safe` (optional): check that the insert succeeded?
           - `check_keys` (optional): check if keys start with '$' or
-            contain '.', raising `pymongo.errors.InvalidName` in either case
+            contain '.', raising :class:`~pymongo.errors.InvalidName`
+            in either case
+          - `**kwargs` (optional): any additional arguments imply
+            ``safe=True``, and will be used as options for the
+            `getLastError` command
 
+        .. versionadded:: 1.8
+           Support for passing `getLastError` options as keyword
+           arguments.
         .. versionchanged:: 1.1
            Bulk insert works with any iterable
 
@@ -229,14 +263,17 @@ class Collection(object):
         if manipulate:
             docs = [self.__database._fix_incoming(doc, self) for doc in docs]
 
+        if kwargs:
+            safe = True
         self.__database.connection._send_message(
-            message.insert(self.__full_name, docs, check_keys, safe), safe)
+            message.insert(self.__full_name, docs,
+                           check_keys, safe, kwargs), safe)
 
         ids = [doc.get("_id", None) for doc in docs]
         return return_one and ids[0] or ids
 
-    def update(self, spec, document,
-               upsert=False, manipulate=False, safe=False, multi=False):
+    def update(self, spec, document, upsert=False, manipulate=False,
+               safe=False, multi=False, **kwargs):
         """Update a document(s) in this collection.
 
         Raises :class:`TypeError` if either `spec` or `document` is
@@ -266,6 +303,11 @@ class Collection(object):
         If `safe` is ``True`` returns the response to the *lastError*
         command. Otherwise, returns ``None``.
 
+        Any additional keyword arguments imply ``safe=True``, and will
+        be used as options for the resultant `getLastError`
+        command. For example, to wait for replication to 3 nodes, pass
+        ``w=3``.
+
         :Parameters:
           - `spec`: a ``dict`` or :class:`~pymongo.son.SON` instance
             specifying elements which must be present for a document
@@ -274,7 +316,7 @@ class Collection(object):
             instance specifying the document to be used for the update
             or (in the case of an upsert) insert - see docs on MongoDB
             `update modifiers`_
-          - `upsert` (optional): perform an `upsert`_ if ``True``
+          - `upsert` (optional): perform an upsert if ``True``
           - `manipulate` (optional): manipulate the document before
             updating? If ``True`` all instances of
             :mod:`~pymongo.son_manipulator.SONManipulator` added to
@@ -287,14 +329,19 @@ class Collection(object):
             might eventually change to ``True``. It is recommended
             that you specify this argument explicitly for all update
             operations in order to prepare your code for that change.
+          - `**kwargs` (optional): any additional arguments imply
+            ``safe=True``, and will be used as options for the
+            `getLastError` command
 
+        .. versionadded:: 1.8
+           Support for passing `getLastError` options as keyword
+           arguments.
         .. versionchanged:: 1.4
            Return the response to *lastError* if `safe` is ``True``.
         .. versionadded:: 1.1.1
            The `multi` parameter.
 
         .. _update modifiers: http://www.mongodb.org/display/DOCS/Updating
-        .. _upsert: http://www.mongodb.org/display/DOCS/Updating#Updating-Upserts
 
         .. mongodoc:: update
         """
@@ -308,11 +355,26 @@ class Collection(object):
         if upsert and manipulate:
             document = self.__database._fix_incoming(document, self)
 
+        if kwargs:
+            safe = True
+
         return self.__database.connection._send_message(
             message.update(self.__full_name, upsert, multi,
-                           spec, document, safe), safe)
+                           spec, document, safe, kwargs), safe)
 
-    def remove(self, spec_or_id=None, safe=False):
+    def drop(self):
+        """Alias for :meth:`~pymongo.database.Database.drop_collection`.
+
+        The following two calls are equivalent:
+
+          >>> db.foo.drop()
+          >>> db.drop_collection("foo")
+
+        .. versionadded:: 1.8
+        """
+        self.__database.drop_collection(self.__name)
+
+    def remove(self, spec_or_id=None, safe=False, **kwargs):
         """Remove a document(s) from this collection.
 
         .. warning:: Calls to :meth:`remove` should be performed with
@@ -332,12 +394,22 @@ class Collection(object):
         If `safe` is ``True`` returns the response to the *lastError*
         command. Otherwise, returns ``None``.
 
+        Any additional keyword arguments imply ``safe=True``, and will
+        be used as options for the resultant `getLastError`
+        command. For example, to wait for replication to 3 nodes, pass
+        ``w=3``.
+
         :Parameters:
           - `spec_or_id` (optional): a dictionary specifying the
             documents to be removed OR any other type specifying the
             value of ``"_id"`` for the document to be removed
           - `safe` (optional): check that the remove succeeded?
+          - `**kwargs` (optional): any additional arguments imply
+            ``safe=True``, and will be used as options for the
+            `getLastError` command
 
+        .. versionadded:: 1.8
+           Support for passing `getLastError` options as keyword arguments.
         .. versionchanged:: 1.7
            Accept any type other than a ``dict`` instance for removal
            by ``"_id"``, not just :class:`~pymongo.objectid.ObjectId`
@@ -358,8 +430,11 @@ class Collection(object):
         if not isinstance(spec_or_id, dict):
             spec_or_id = {"_id": spec_or_id}
 
+        if kwargs:
+            safe = True
+
         return self.__database.connection._send_message(
-            message.delete(self.__full_name, spec_or_id, safe), safe)
+            message.delete(self.__full_name, spec_or_id, safe, kwargs), safe)
 
     def find_one(self, spec_or_id=None, *args, **kwargs):
         """Get a single document from the database.
@@ -422,8 +497,7 @@ class Collection(object):
             result set
           - `fields` (optional): a list of field names that should be
             returned in the result set ("_id" will always be
-            included), or a dict specifying the `fields to return
-            <http://www.mongodb.org/display/DOCS/Advanced+Queries#AdvancedQueries-RetrievingaSubsetofFields>`_
+            included), or a dict specifying the fields to return
           - `skip` (optional): the number of documents to omit (from
             the start of the result set) when returning the results
           - `limit` (optional): the maximum number of results to
@@ -438,7 +512,7 @@ class Collection(object):
             returned, or objects missed, which were present at both
             the start and end of the query's execution. For details,
             see the `snapshot documentation
-            <http://www.mongodb.org/display/DOCS/How+to+do+Snapshotting+in+the+Mongo+Database>`_.
+            <http://dochub.mongodb.org/core/snapshot>`_.
           - `tailable` (optional): the result of this find call will
             be a tailable cursor - tailable cursors aren't closed when
             the last data is retrieved but are kept open and the
@@ -455,10 +529,16 @@ class Collection(object):
           - `as_class` (optional): class to use for documents in the
             query result (default is
             :attr:`~pymongo.connection.Connection.document_class`)
+          - `network_timeout` (optional): specify a timeout to use for
+            this query, which will override the
+            :class:`~pymongo.connection.Connection`-level default
 
         .. note:: The `max_scan` parameter requires server
            version **>= 1.5.1**
 
+        .. versionadded:: 1.8
+           The `network_timeout` parameter.
+
         .. versionadded:: 1.7
            The `sort`, `max_scan` and `as_class` parameters.
 
@@ -496,8 +576,8 @@ class Collection(object):
 
         >>> my_collection.create_index("mike")
 
-        For a `compound index`_ on ``'mike'`` descending and
-        ``'eliot'`` ascending we need to use a list of tuples:
+        For a compound index on ``'mike'`` descending and ``'eliot'``
+        ascending we need to use a list of tuples:
 
         >>> my_collection.create_index([("mike", pymongo.DESCENDING),
         ...                             ("eliot", pymongo.ASCENDING)])
@@ -535,8 +615,6 @@ class Collection(object):
 
         .. seealso:: :meth:`ensure_index`
 
-        .. _compound index: http://www.mongodb.org/display/DOCS/Indexes#Indexes-CompoundKeysIndexes
-
         .. mongodoc:: indexes
         """
         keys = helpers._index_list(key_or_list)
