@@ -38,7 +38,8 @@ class Cursor(object):
     def __init__(self, collection, spec=None, fields=None, skip=0, limit=0,
                  timeout=True, snapshot=False, tailable=False, sort=None,
                  max_scan=None, as_class=None,
-                 _sock=None, _must_use_master=False, _is_command=False):
+                 _must_use_master=False, _is_command=False,
+                 **kwargs):
         """Create a new cursor.
 
         Should not be called directly by application developers - see
@@ -86,7 +87,7 @@ class Cursor(object):
         self.__explain = False
         self.__hint = None
         self.__as_class = as_class
-        self.__socket = _sock
+        self.__tz_aware = collection.database.connection.tz_aware
         self.__must_use_master = _must_use_master
         self.__is_command = _is_command
 
@@ -95,6 +96,10 @@ class Cursor(object):
         self.__retrieved = 0
         self.__killed = False
 
+        # this is for passing network_timeout through if it's specified
+        # need to use kwargs as None is a legit value for network_timeout
+        self.__kwargs = kwargs
+
     @property
     def collection(self):
         """The :class:`~pymongo.collection.Collection` that this
@@ -139,7 +144,6 @@ class Cursor(object):
         copy.__ordering = self.__ordering
         copy.__explain = self.__explain
         copy.__hint = self.__hint
-        copy.__socket = self.__socket
         return copy
 
     def __die(self):
@@ -193,8 +197,9 @@ class Cursor(object):
         """Limits the number of results to be returned by this cursor.
 
         Raises TypeError if limit is not an instance of int. Raises
-        InvalidOperation if this cursor has already been used. The last `limit`
-        applied to this cursor takes precedence.
+        InvalidOperation if this cursor has already been used. The
+        last `limit` applied to this cursor takes precedence. A limit
+        of ``0`` is equivalent to no limit.
 
         :Parameters:
           - `limit`: the number of results to return
@@ -468,10 +473,10 @@ class Cursor(object):
         """Send a query or getmore message and handles the response.
         """
         db = self.__collection.database
-        kwargs = {"_sock": self.__socket,
-                  "_must_use_master": self.__must_use_master}
+        kwargs = {"_must_use_master": self.__must_use_master}
         if self.__connection_id is not None:
             kwargs["_connection_to_use"] = self.__connection_id
+        kwargs.update(self.__kwargs)
 
         response = db.connection._send_message_with_response(message,
                                                              **kwargs)
@@ -485,9 +490,10 @@ class Cursor(object):
 
         try:
             response = helpers._unpack_response(response, self.__id,
-                                                self.__as_class)
+                                                self.__as_class,
+                                                self.__tz_aware)
         except AutoReconnect:
-            db.connection._reset()
+            db.connection.disconnect()
             raise
         self.__id = response["cursor_id"]
 
