@@ -222,7 +222,7 @@ class Database(object):
         return son
 
     def command(self, command, value=1,
-                check=True, allowable_errors=[], _sock=None, **kwargs):
+                check=True, allowable_errors=[], **kwargs):
         """Issue a MongoDB command.
 
         Send command `command` to the database and return the
@@ -283,7 +283,7 @@ class Database(object):
 
         command.update(kwargs)
 
-        result = self["$cmd"].find_one(command, _sock=_sock,
+        result = self["$cmd"].find_one(command,
                                        _must_use_master=True,
                                        _is_command=True)
 
@@ -391,7 +391,7 @@ class Database(object):
         if error.get("err", 0) is None:
             return None
         if error["err"] == "not master":
-            self.__connection._reset()
+            self.__connection.disconnect()
         return error
 
     def last_status(self):
@@ -570,7 +570,7 @@ class Database(object):
         """This is only here so that some API misusages are easier to debug.
         """
         raise TypeError("'Database' object is not callable. If you meant to "
-                        "call the '%s' method on a 'Collection' object it is "
+                        "call the '%s' method on a 'Connection' object it is "
                         "failing because no such method exists." % self.__name)
 
 
@@ -586,7 +586,7 @@ class SystemJS(object):
         manual instantiation of this class should not be necessary.
 
         :class:`SystemJS` instances allow for easy manipulation and
-        access to `server-side JavaScript`_:
+        access to server-side JavaScript:
 
         .. doctest::
 
@@ -602,8 +602,6 @@ class SystemJS(object):
         .. note:: Requires server version **>= 1.1.1**
 
         .. versionadded:: 1.5
-
-        .. _server-side JavaScript: http://www.mongodb.org/display/DOCS/Server-side+Code+Execution#Server-sideCodeExecution-Storingfunctionsserverside
         """
         # can't just assign it since we've overridden __setattr__
         object.__setattr__(self, "_database", database)
