@@ -61,8 +61,12 @@ class TestDBRef(unittest.TestCase):
                          "DBRef('coll', ObjectId('1234567890abcdef12345678'))")
         self.assertEqual(repr(DBRef(u"coll", ObjectId("1234567890abcdef12345678"))),
                          "DBRef(u'coll', ObjectId('1234567890abcdef12345678'))")
+        self.assertEqual(repr(DBRef("coll", 5, foo="bar")),
+                         "DBRef('coll', 5, foo='bar')")
         self.assertEqual(repr(DBRef("coll", ObjectId("1234567890abcdef12345678"), "foo")),
                          "DBRef('coll', ObjectId('1234567890abcdef12345678'), 'foo')")
+        self.assertEqual(repr(DBRef("coll", 5, "baz", foo="bar", baz=4)),
+                         "DBRef('coll', 5, 'baz', foo='bar', baz=4)")
 
     def test_cmp(self):
         self.assertEqual(DBRef("coll", ObjectId("1234567890abcdef12345678")),
@@ -79,6 +83,13 @@ class TestDBRef(unittest.TestCase):
         self.assertNotEqual(DBRef("coll", ObjectId("1234567890abcdef12345678"), "foo"),
                             DBRef(u"coll", ObjectId("1234567890abcdef12345678"), "bar"))
 
+    def test_kwargs(self):
+        self.assertEqual(DBRef("coll", 5, foo="bar"), DBRef("coll", 5, foo="bar"))
+        self.assertNotEqual(DBRef("coll", 5, foo="bar"), DBRef("coll", 5))
+        self.assertNotEqual(DBRef("coll", 5, foo="bar"), DBRef("coll", 5, foo="baz"))
+        self.assertEqual("bar", DBRef("coll", 5, foo="bar").foo)
+        self.assertRaises(KeyError, getattr, DBRef("coll", 5, foo="bar"), "bar")
+
 
 if __name__ == "__main__":
     unittest.main()
