@@ -193,8 +193,8 @@ class TestGridfs(unittest.TestCase):
         self.assert_(self.fs.exists({"_id": oid}))
         self.assert_(self.fs.exists(_id=oid))
 
-        self.failIf(self.fs.exists(filename="mike"))
-        self.failIf(self.fs.exists("mike"))
+        self.assertFalse(self.fs.exists(filename="mike"))
+        self.assertFalse(self.fs.exists("mike"))
 
         oid = self.fs.put("hello", filename="mike", foo=12)
         self.assert_(self.fs.exists(oid))
@@ -207,10 +207,10 @@ class TestGridfs(unittest.TestCase):
         self.assert_(self.fs.exists(foo={"$gt": 11}))
         self.assert_(self.fs.exists({"foo": {"$gt": 11}}))
 
-        self.failIf(self.fs.exists(foo=13))
-        self.failIf(self.fs.exists({"foo": 13}))
-        self.failIf(self.fs.exists(foo={"$gt": 12}))
-        self.failIf(self.fs.exists({"foo": {"$gt": 12}}))
+        self.assertFalse(self.fs.exists(foo=13))
+        self.assertFalse(self.fs.exists({"foo": 13}))
+        self.assertFalse(self.fs.exists(foo={"$gt": 12}))
+        self.assertFalse(self.fs.exists({"foo": {"$gt": 12}}))
 
 
 if __name__ == "__main__":
