@@ -34,6 +34,10 @@ sys.path[0:0] = [""]
 from pymongo.json_util import default, object_hook
 from pymongo.objectid import ObjectId
 from pymongo.dbref import DBRef
+from pymongo.min_key import MinKey
+from pymongo.max_key import MaxKey
+from pymongo.timestamp import Timestamp
+from pymongo.tz_util import utc
 
 class TestJsonUtil(unittest.TestCase):
 
@@ -57,17 +61,32 @@ class TestJsonUtil(unittest.TestCase):
     def test_dbref(self):
         self.round_trip({"ref": DBRef("foo", 5)})
         self.round_trip({"ref": DBRef("foo", 5, "db")})
+        self.assertEqual("{\"ref\": {\"$ref\": \"foo\", \"$id\": 5}}",
+                         json.dumps({"ref": DBRef("foo", 5)}, default=default))
+        self.assertEqual("{\"ref\": {\"$ref\": \"foo\", \"$id\": 5, \"$db\": \"bar\"}}",
+                         json.dumps({"ref": DBRef("foo", 5, "bar")}, default=default))
 
     def test_datetime(self):
         # only millis, not micros
         self.round_trip({"date": datetime.datetime(2009, 12, 9, 15,
-                                                   49, 45, 191000)})
+                                                   49, 45, 191000, utc)})
 
     def test_regex(self):
         res = self.round_tripped({"r": re.compile("a*b", re.IGNORECASE)})["r"]
         self.assertEqual("a*b", res.pattern)
         self.assertEqual(re.IGNORECASE, res.flags)
 
+    def test_minkey(self):
+        self.round_trip({"m" : MinKey()})
+
+    def test_maxkey(self):
+        self.round_trip({"m" : MinKey()})
+
+    def test_timestamp(self):
+        res = json.dumps({"ts" : Timestamp(4, 13)}, default=default)
+        dct = json.loads(res);
+        self.assertEqual(dct['ts']['t'], 4)
+        self.assertEqual(dct['ts']['i'], 13)
 
 if __name__ == "__main__":
     unittest.main()
