@@ -14,10 +14,12 @@
 
 """Simple script to help test auto-reconnection."""
 
+import sys
 import threading
 import time
+sys.path[0:0] = [""]
 
-from pymongo.errors import ConnectionFailure
+from pymongo.errors import AutoReconnect
 from pymongo.connection import Connection
 
 db = Connection.paired(("localhost", 27018)).test
@@ -28,12 +30,12 @@ class Something(threading.Thread):
         while True:
             time.sleep(1)
             try:
-                id = db.test.save({"x": 1})
+                id = db.test.save({"x": 1}, safe=True)
                 assert db.test.find_one(id)["x"] == 1
                 db.test.remove(id)
                 db.connection.end_request()
                 print "Y"
-            except ConnectionFailure, e:
+            except AutoReconnect, e:
                 print e
                 print "N"
 
